@@ -1,20 +1,33 @@
+"""
+The game module includes lightweight data classes:
+- Player
+    - The player class keeps track of the chips, player_state,
+      last_pot, and player_id of the player.
+- Pot
+    - The pot class represents a betting pot which players
+      can post to. Includes helper functions and attributes that deal
+      with split pots or how much a player needs to call.
+
+It also includes the main TexasHoldEm class of the texasholdem package.
+"""
+
 from __future__ import annotations
 
-from typing import Iterator, Callable, Dict, Tuple, Union
+from typing import Iterator, Callable, Dict, Tuple, Union, Optional
 from enum import Enum, auto
 import random
 
 from texasholdem.card.card import Card
 from texasholdem.card.deck import Deck
-from texasholdem.game.history import *
+from texasholdem.game.history import PrehandHistory, BettingRoundHistory, PlayerAction
 from texasholdem.game.action_type import ActionType
 from texasholdem.game.hand_phase import HandPhase
 from texasholdem.game.player_state import PlayerState
 from texasholdem.evaluator import evaluator
-from texasholdem.game.errors import PokerError
 
 
 class Player:
+    # pylint: disable=too-few-public-methods
     """
     The TexasHoldEm object uses this Player as a bookkeeping mechanism for:
         - Chip count
@@ -22,8 +35,8 @@ class Player:
         - Which pots the player is in
     """
 
-    def __init__(self, id, chips):
-        self.id = id
+    def __init__(self, player_id, chips):
+        self.player_id = player_id
         self.chips = chips
         self.state = PlayerState.IN
 
@@ -44,62 +57,74 @@ class Pot:
         self.raised = 0
         self.player_amounts = {}
 
-    def chips_to_call(self, id: int) -> int:
+    def chips_to_call(self, player_id: int) -> int:
         """Returns the amount of chips to call for the given player.
 
         Args:
-            id (int): The id of the player in the pot
+            player_id (int): The player_id of the player in the pot
         Returns:
             int: The amount the player needs to call to be in this pot
               (this is just self.raised if the player hasn't bet yet)
 
         """
-        return self.raised - self.player_amounts.get(id, 0)
+        return self.raised - self.player_amounts.get(player_id, 0)
 
-    def player_post(self, id: int, amount: int):
-        """The given player posts amount into this pot. If player[id].amount > raised,
+    def player_post(self, player_id: int, amount: int):
+        """The given player posts amount into this pot. If player[player_id].amount > raised,
         sets new raised value.
 
         Arguments:
-            id (int): The id of the player posting
+            player_id (int): The player_id of the player posting
             amount (int): The amount to post into this pot
 
         """
-        self.player_amounts[id] = self.player_amounts.get(id, 0) + amount
+        self.player_amounts[player_id] = self.player_amounts.get(player_id, 0) + amount
 
-        if self.player_amounts[id] > self.raised:
-            self.raised = self.player_amounts[id]
+        if self.player_amounts[player_id] > self.raised:
+            self.raised = self.player_amounts[player_id]
 
-    def get_player_amount(self, id: int) -> int:
+    def get_player_amount(self, player_id: int) -> int:
         """
         Arguments:
-            id (int): Player id
+            player_id (int): Player player_id
         Returns:
             int: the amount the player has bet currently for this pot.
 
         """
-        return self.player_amounts.get(id, 0)
+        return self.player_amounts.get(player_id, 0)
 
     def players_in_pot(self) -> Iterator[int]:
         """
         Returns:
-            Iterator[int]: An iterator over the player id's that have a stake in this pot.
+            Iterator[int]: An iterator over the player player_id's that have a stake in this pot.
 
         """
 
         return iter(self.player_amounts.keys())
 
     def collect_bets(self):
+        """
+        Collects all the bets players made this round and adds them to
+        the total amount. Resets player betting.
+        """
         self.raised = 0
-        for id in self.player_amounts:
-            self.amount += self.player_amounts[id]
-            self.player_amounts[id] = 0
+        for player_id, player_amount in self.player_amounts.items():
+            self.amount += player_amount
+            self.player_amounts[player_id] = 0
 
-    def remove_player(self, id: int):
-        if id not in self.player_amounts:
+    def remove_player(self, player_id: int):
+        """
+        Removes the given player from the pot and adds their betting
+        to the total amount.
+
+        Arguments:
+            player_id (int): Player player_id
+
+        """
+        if player_id not in self.player_amounts:
             return
 
-        self.amount += self.player_amounts.pop(id)
+        self.amount += self.player_amounts.pop(player_id)
 
     def get_amount(self) -> int:
         """
@@ -138,12 +163,12 @@ class Pot:
         split_pot.raised = self.raised - raised_level
         self.raised = raised_level
 
-        for id in self.players_in_pot():
+        for player_id in self.players_in_pot():
             # player currently in last pot, post overflow to the split pot
-            if self.get_player_amount(id) > self.raised:
-                overflow = self.get_player_amount(id) - self.raised
-                split_pot.player_post(id, overflow)
-                self.player_amounts[id] -= -overflow
+            if self.get_player_amount(player_id) > self.raised:
+                overflow = self.get_player_amount(player_id) - self.raised
+                split_pot.player_post(player_id, overflow)
+                self.player_amounts[player_id] -= -overflow
 
         return split_pot
 
@@ -160,6 +185,8 @@ class GameState(Enum):
 
 
 class TexasHoldEm:
+    # pylint: disable=too-many-instance-attributes,stop-iteration-return
+
     """
     Represents a table of TexasHoldEm (tournament style).
 
@@ -233,16 +260,16 @@ class TexasHoldEm:
         dealing cards and setup for preflop.
         """
         if self.hand_phase != HandPhase.PREHAND:
-            raise PokerError("Not time for prehand!")
+            raise ValueError("Not time for prehand!")
 
         # set statuses for players
-        for id in self.player_iter(loc=0):
-            self.players[id].last_pot = 0
+        for player_id in self.player_iter(loc=0):
+            self.players[player_id].last_pot = 0
 
-            if self.players[id].chips == 0:
-                self.players[id].state = PlayerState.SKIP
+            if self.players[player_id].chips == 0:
+                self.players[player_id].state = PlayerState.SKIP
             else:
-                self.players[id].state = PlayerState.TO_CALL
+                self.players[player_id].state = PlayerState.TO_CALL
 
         active_players = list(self.active_iter(self.btn_loc + 1))
 
@@ -286,8 +313,8 @@ class TexasHoldEm:
         self.hands = {}
         self.board = []
 
-        for id in self.active_iter(self.btn_loc + 1):
-            self.hands[id] = self._deck.draw(n=2)
+        for player_id in self.active_iter(self.btn_loc + 1):
+            self.hands[player_id] = self._deck.draw(num=2)
 
         # action to left of BB
         self.current_player = next(self.active_iter(loc=self.bb_loc + 1))
@@ -295,11 +322,11 @@ class TexasHoldEm:
 
     def player_iter(self, loc: int = None) -> Iterator[int]:
         """
-        Iterates through all players starting at id and rotating in order
-        of increasing id.
+        Iterates through all players starting at player_id and rotating in order
+        of increasing player_id.
 
         Arguments:
-            loc (int)       - The id to start at, default is current_player.
+            loc (int)       - The player_id to start at, default is current_player.
         Returns:
             (Iterator[int]) - An iterator over all the players.
         """
@@ -321,9 +348,9 @@ class TexasHoldEm:
         """
         if loc is None:
             loc = self.current_player
-        for id in self.player_iter(loc=loc):
-            if self.players[id].state not in (PlayerState.OUT, PlayerState.SKIP):
-                yield id
+        for player_id in self.player_iter(loc=loc):
+            if self.players[player_id].state not in (PlayerState.OUT, PlayerState.SKIP):
+                yield player_id
 
     def in_pot_iter(self, loc: int = None) -> Iterator[int]:
         """
@@ -338,9 +365,9 @@ class TexasHoldEm:
         """
         if loc is None:
             loc = self.current_player
-        for id in self.active_iter(loc=loc):
-            if self.players[id].state in (PlayerState.IN, PlayerState.TO_CALL):
-                yield id
+        for player_id in self.active_iter(loc=loc):
+            if self.players[player_id].state in (PlayerState.IN, PlayerState.TO_CALL):
+                yield player_id
 
     def _split_pot(self, pot_id: int, raised_level: int):
         """
@@ -372,7 +399,7 @@ class TexasHoldEm:
         pots (i.e. split pots).
 
         Arguments:
-            player_id (int) - The ID of the player posting
+            player_id (int) - The player_id of the player posting
             amount (int)	- The amount to post
         """
         amount = min(self.players[player_id].chips, amount)
@@ -395,10 +422,10 @@ class TexasHoldEm:
 
         # players previously in pot need to call in event of a raise
         if amount > chips_to_call:
-            for id in self._get_pot(last_pot).players_in_pot():
-                if self._get_pot(last_pot).chips_to_call(id) > 0 and \
-                   self.players[id].state == PlayerState.IN:
-                    self.players[id].state = PlayerState.TO_CALL
+            for pot_player_id in self._get_pot(last_pot).players_in_pot():
+                if self._get_pot(last_pot).chips_to_call(pot_player_id) > 0 and \
+                   self.players[pot_player_id].state == PlayerState.IN:
+                    self.players[pot_player_id].state = PlayerState.TO_CALL
 
         # if a player is all_in in this pot, split a new one off
         if PlayerState.ALL_IN in (self.players[i].state
@@ -413,15 +440,15 @@ class TexasHoldEm:
     def _get_pot(self, pot_id: int) -> Pot:
         """
         Arguments:
-            pot_id (int): The ID of the pot to get
+            pot_id (int): The player_id of the pot to get
         Returns:
-            Pot: The pot with given ID
+            Pot: The pot with given player_id
         Raises:
-            ValueError: If a pot with ID pot_id does not exist.
+            ValueError: If a pot with player_id pot_id does not exist.
 
         """
         if pot_id >= len(self.pots):
-            raise ValueError(f"Pot with id {pot_id} does not exist.")
+            raise ValueError(f"Pot with player_id {pot_id} does not exist.")
 
         return self.pots[pot_id]
 
@@ -436,7 +463,7 @@ class TexasHoldEm:
     def _last_pot_id(self) -> int:
         """
         Returns:
-            int: The pot id of the last pot.
+            int: The pot player_id of the last pot.
 
         """
         return len(self.pots) - 1
@@ -450,7 +477,8 @@ class TexasHoldEm:
         for i in self.in_pot_iter():
             if self.players[i].state == PlayerState.TO_CALL:
                 return False
-            elif self.players[i].state == PlayerState.IN:
+
+            if self.players[i].state == PlayerState.IN:
                 count += 1
 
             if count > 1:
@@ -462,7 +490,7 @@ class TexasHoldEm:
         Runs the PREFLOP sequence
         """
         if self.hand_phase != HandPhase.PREFLOP:
-            raise PokerError("Not time for PREFLOP!")
+            raise ValueError("Not time for PREFLOP!")
 
         self.current_player = next(self.active_iter(loc=self.bb_loc + 1))
         yield from self._betting_round()
@@ -472,9 +500,9 @@ class TexasHoldEm:
         Runs the FLOP sequence
         """
         if self.hand_phase != HandPhase.FLOP:
-            raise PokerError("Not time for PREFLOP!")
+            raise ValueError("Not time for PREFLOP!")
 
-        self.board.extend(self._deck.draw(n=3))
+        self.board.extend(self._deck.draw(num=3))
         self.current_player = next(self.active_iter(loc=self.btn_loc + 1))
         yield from self._betting_round()
 
@@ -483,9 +511,9 @@ class TexasHoldEm:
         Runs the TURN sequence
         """
         if self.hand_phase != HandPhase.TURN:
-            raise PokerError("Not time for Turn!")
+            raise ValueError("Not time for Turn!")
 
-        self.board.extend(self._deck.draw(n=1))
+        self.board.extend(self._deck.draw(num=1))
         self.current_player = next(self.active_iter(loc=self.btn_loc + 1))
         yield from self._betting_round()
 
@@ -494,9 +522,9 @@ class TexasHoldEm:
         Runs the RIVER sequence
         """
         if self.hand_phase != HandPhase.RIVER:
-            raise PokerError("Not time for River!")
+            raise ValueError("Not time for River!")
 
-        self.board.extend(self._deck.draw(n=1))
+        self.board.extend(self._deck.draw(num=1))
         self.current_player = next(self.active_iter(loc=self.btn_loc + 1))
         yield from self._betting_round()
 
@@ -506,145 +534,150 @@ class TexasHoldEm:
         the board has 5 card before settling.
         """
         if self.hand_phase != HandPhase.SETTLE:
-            raise PokerError("Not time for Settle!")
+            raise ValueError("Not time for Settle!")
 
         self.current_player = next(self.active_iter(loc=self.btn_loc + 1))
 
-        for i in range(len(self.pots)):
-            players_in_pot = list(self.pots[i].players_in_pot())
+        for pot in self.pots:
+            players_in_pot = list(pot.players_in_pot())
             # only player left in pot wins
             if len(players_in_pot) == 1:
-                self.players[players_in_pot[0]].chips += self.pots[i].get_total_amount()
+                self.players[players_in_pot[0]].chips += pot.get_total_amount()
                 continue
 
             # make sure there is 5 cards on the board
             if len(self.board) < 5:
-                self.board.extend(self._deck.draw(n=5 - len(self.board)))
+                self.board.extend(self._deck.draw(num=5 - len(self.board)))
 
             player_ranks = {}
-            for id in players_in_pot:
-                player_ranks[id] = evaluator.evaluate(self.hands[id], self.board)
+            for player_id in players_in_pot:
+                player_ranks[player_id] = evaluator.evaluate(self.hands[player_id], self.board)
 
             best_rank = min(player_ranks.values())
-            winners = [id for id in player_ranks if player_ranks[id] == best_rank]
+            winners = [player_id
+                       for player_id, player_rank in player_ranks.items()
+                       if player_rank == best_rank]
 
-            win_amount = (self.pots[i].get_total_amount()) / len(winners)
+            win_amount = (pot.get_total_amount()) / len(winners)
             win_amount = round(win_amount)
-            for id in winners:
-                self.players[id].chips += win_amount
+            for player_id in winners:
+                self.players[player_id].chips += win_amount
 
-    def chips_to_call(self, id: int) -> int:
+    def chips_to_call(self, player_id: int) -> int:
         """
         Arguments:
-            id (int) - The player id
+            player_id (int) - The player player_id
         Returns:
             int - The amount of chips the player needs to call in all pots
                   to play the hand.
         """
-        return sum(self._get_pot(i).chips_to_call(id) for i in range(len(self.pots)))
+        return sum(self._get_pot(i).chips_to_call(player_id) for i in range(len(self.pots)))
 
-    def player_bet_amount(self, id: int) -> int:
+    def player_bet_amount(self, player_id: int) -> int:
         """
         Arguments:
-            id (int) - The player id
+            player_id (int) - The player player_id
         Returns:
             int - The amount of chips the player bet this round across all
                   pots.
         """
-        return sum(self._get_pot(i).get_player_amount(id) for i in range(len(self.pots)))
+        return sum(self._get_pot(i).get_player_amount(player_id) for i in range(len(self.pots)))
 
-    def chips_at_stake(self, id: int) -> int:
+    def chips_at_stake(self, player_id: int) -> int:
         """
         Arguments:
-            id (int) - The player id
+            player_id (int) - The player player_id
         Returns:
             int - The amount of chips the player is eligible to win
         """
         return sum(self._get_pot(i).get_total_amount()
                    for i in range(len(self.pots))
-                   if id in self._get_pot(i).players_in_pot())
+                   if player_id in self._get_pot(i).players_in_pot())
 
-    def validate_move(self, id: int, action: ActionType, value: Optional[int] = None) -> bool:
+    def validate_move(self, player_id: int,
+                      action: ActionType,
+                      value: Optional[int] = None) -> bool:
         """
-        Validate the potentially invalid action for the given player.
+        Validate the potentially invalplayer_id action for the given player.
 
         Arguments:
-            id (int): the player to take action
+            player_id (int): the player to take action
             action (ActionType): The ActionType to take
             value (int, optional): In the case of raise, how much to raise
         Returns:
-            bool: True if the move is valid, False o/w
+            bool: True if the move is valplayer_id, False o/w
         """
         # ALL_IN should be translated
         new_action, new_value = action, value
         if new_action == ActionType.ALL_IN:
             new_action, new_value = self._translate_allin(new_action, new_value)
 
-        player_amount = self.player_bet_amount(id)
-        chips_to_call = self.chips_to_call(id)
+        player_amount = self.player_bet_amount(player_id)
+        chips_to_call = self.chips_to_call(player_id)
 
-        # Check if player id is current player
-        if self.current_player != id:
+        # Check if player player_id is current player
+        if self.current_player != player_id:
             return False
 
         if new_action == ActionType.CALL:
-            return self.players[id].state == PlayerState.TO_CALL
-        elif new_action == ActionType.CHECK:
-            return self.players[id].state == PlayerState.IN
-        elif new_action == ActionType.RAISE:
-            if new_value is None:
-                return False
-
-            if (new_value < self.big_blind and action != ActionType.ALL_IN) or \
-               player_amount + self.players[id].chips < new_value or \
-               new_value < chips_to_call:
-                return False
-
+            return self.players[player_id].state == PlayerState.TO_CALL
+        if new_action == ActionType.CHECK:
+            return self.players[player_id].state == PlayerState.IN
+        if new_action == ActionType.RAISE:
+            return not (
+               new_value is None or
+               (new_value < self.big_blind and action != ActionType.ALL_IN) or
+               player_amount + self.players[player_id].chips < new_value or
+               new_value < chips_to_call
+            )
+        if new_action == ActionType.FOLD:
             return True
-        elif new_action == ActionType.FOLD:
-            return True
-        else:
-            return False
 
-    def _safe_execute(self, id: int, action: ActionType, value: Optional[int] = None) -> bool:
+        return False
+
+    def _safe_execute(self, player_id: int,
+                      action: ActionType,
+                      value: Optional[int] = None) -> bool:
         """
-        Safely execute the potentially invalid action for the given player.
+        Safely execute the potentially invalplayer_id action for the given player.
 
         Arguments:
-            id (int) 				- the player to take action
+            player_id (int) 				- the player to take action
             action (ActionType) 	- The ActionType to take
             value (Optional[int]) - In the case of raise, how much to raise
         Returns:
             bool - True if successfully executed, False otherwise
         """
         # Validate move
-        if not self.validate_move(id, action, value):
+        if not self.validate_move(player_id, action, value):
             return False
 
         # ALL_IN should be translated
         if action == ActionType.ALL_IN:
             action, value = self._translate_allin(action, value)
 
-        player_amount = self.player_bet_amount(id)
-        chips_to_call = self.chips_to_call(id)
+        player_amount = self.player_bet_amount(player_id)
+        chips_to_call = self.chips_to_call(player_id)
 
         # Execute move
         if action == ActionType.CALL:
-            self._player_post(id, chips_to_call)
+            self._player_post(player_id, chips_to_call)
         elif action == ActionType.CHECK:
             pass
         elif action == ActionType.RAISE:
-            self._player_post(id, value - player_amount)
+            self._player_post(player_id, value - player_amount)
         elif action == ActionType.FOLD:
-            self.players[id].state = PlayerState.OUT
-            for i in range(self.players[id].last_pot + 1):
-                self.pots[i].remove_player(id)
+            self.players[player_id].state = PlayerState.OUT
+            for i in range(self.players[player_id].last_pot + 1):
+                self.pots[i].remove_player(player_id)
         else:
             return False
 
         return True
 
-    def _translate_allin(self, action: ActionType, value: int = None) -> Tuple[ActionType, Optional[int]]:
+    def _translate_allin(self,
+                         action: ActionType,
+                         value: int = None) -> Tuple[ActionType, Optional[int]]:
         """
         Translates an all-in action to the appropriate action,
         either call or raise.
@@ -664,12 +697,11 @@ class TexasHoldEm:
         until everyone "checks"
 
         Raises:
-            PokerError - If self.hand_state is not a valid betting round
+            ValueError - If self.hand_state is not a valplayer_id betting round
         """
 
-        if self.hand_phase == HandPhase.PREHAND or \
-                self.hand_phase == HandPhase.SETTLE:
-            raise PokerError("Not valid betting round!")
+        if self.hand_phase in (HandPhase.PREHAND, HandPhase.SETTLE):
+            raise ValueError("Not valplayer_id betting round!")
 
         first_pot = self._last_pot_id()
         player_iter = self.in_pot_iter(self.current_player)
@@ -686,7 +718,7 @@ class TexasHoldEm:
             passed = self._safe_execute(self.current_player, action, val)
 
             if not passed:
-                raise PokerError(f"Invalid move for player {self.current_player}: "
+                raise ValueError(f"Invalplayer_id move for player {self.current_player}: "
                                  f"{action}, {val}")
 
             if self.hand_phase not in self.hand_history:
@@ -714,7 +746,7 @@ class TexasHoldEm:
     def get_hand(self, player_id) -> list[Card]:
         """
         Arguments:
-            player_id (int): The ID of the player
+            player_id (int): The player_id of the player
         Returns:
             list[Card]: A two element list of the hand of the given player,
                 if player has not been dealt a hand, returns an empty list
@@ -727,10 +759,10 @@ class TexasHoldEm:
         Starts a new hand.
 
         Raises:
-            (PokerError)            - If hand already in progress.
+            (ValueError)            - If hand already in progress.
         """
         if self.is_hand_running():
-            raise PokerError('In the middle of a hand!')
+            raise ValueError('In the middle of a hand!')
 
         self.hand_phase = HandPhase.PREHAND
         self._handstate_handler[self.hand_phase]()
@@ -754,15 +786,15 @@ class TexasHoldEm:
             action_type (ActionType) - The action type
             value (Optional[int])    - The value
         Raises:
-            (PokerError)            - If no action can be taken due to GameState.STOPPED
+            (ValueError)            - If no action can be taken due to GameState.STOPPED
                                       or if the move is invalid.
 
         """
         if not self.is_hand_running():
-            raise PokerError("No hand is running")
+            raise ValueError("No hand is running")
 
         if not self.validate_move(self.current_player, action_type, value=value):
-            raise PokerError("Move is invalid!")
+            raise ValueError("Move is invalid!")
 
         self._action = (action_type, value)
 
@@ -777,10 +809,10 @@ class TexasHoldEm:
             (Iterator[TexasHoldEm])	- A generator over every intermediate game state.
                                       i.e. right before every action.
         Raises:
-            (PokerError)            - If phase != PREFLOP
+            (ValueError)            - If phase != PREFLOP
         """
         if self.hand_phase != HandPhase.PREFLOP:
-            raise PokerError("Cannot iterate over hand: not time for PREFLOP")
+            raise ValueError("Cannot iterate over hand: not time for PREFLOP")
 
         while self.is_hand_running():
             if self._is_hand_over():
